/****************************************************************************
 *
 *  Copyright(C) 1997 - 1998 CaseMaker Inc. All rights reserved.
 *
 *  sample program for ESQL/C
 *       . use sqlca, dbenvca as global variable
 *       . connect to database
 *       . insert (name, telno) to info table
 *       . select
 *       . delete
 *       . update
 *       . fetch all data from info table
 *       . disconnect db
 ****************************************************************************/
/* The following structure must include in program */
/* must be accessable in your whole program by either global or pass in func */
EXEC SQL include sqlca;            /* declare global */
EXEC SQL include dbenvca;          /* declare global */

/* This macro is for checking and showing error and warning message */
#define chkErr() \
        { \
        if (SQLCODE && SQLCODE != SQL_NO_DATA_FOUND) \
           { \
           if (SQLCODE == SQL_SUCCESS_WITH_INFO) \
              printf("WARN(%d):%s\n", sqlca.sqlerrd[0], sqlca.sqlerrmc); \
           else \
              { \
              printf("ERR(%d):%s\n", sqlca.sqlerrd[0], sqlca.sqlerrmc); \
              goto program_exit; \
              } \
           } \
        }

main()
{
   EXEC SQL begin declare section;
   char user[8], passwd[8];           /* connection information         */
   char dbname[18];                   /* char type is fix length string */
   char name[21], tel[21];
   int  ind1 = SQL_NTS;
   EXEC SQL end declare section;

   strcpy(dbname, "DBSAMPLE4");          /* get db,user,password info */
   strcpy(user, "SYSADM");
   strcpy(passwd, "");

   /* you can also directly type EXEC SQL connect to db_name user_id passwd */
   EXEC SQL connect to :dbname :user :passwd;

   /* clear all tuple in info table */
   /* it's for making sure every time run this program will get same result */
   EXEC SQL delete from info;

   /* set autocommit mode off */
   EXEC SQL set autocommit off;

   /* test EXEC SQL INSERT (name, tel) */
   strcpy(name, "John Smith");
   strcpy(tel, "7654321");
   EXEC SQL insert into info values (:name :ind1, :tel :ind1);
   chkErr();       /* if any error occur, print out error */

   /* test EXEC SQL INSERT (name, tel) */
   strcpy(name, "Mary Black");
   strcpy(tel, "7418010");
   EXEC SQL insert into info values (:name :ind1, :tel :ind1);
   chkErr();       /* if any error occur, print out error */

   /* test EXEC SQL INSERT (name, tel) */
   strcpy(name, "Jane White");
   strcpy(tel, "1111111");
   EXEC SQL insert into info values (:name :ind1, :tel :ind1);
   chkErr();       /* if any error occur, print out error */

   /* test EXEC SQL SELECT (query John Smith's telephone number */
   strcpy(name, "John Smith");
   EXEC SQL select tel from info where name = :name :ind1 into :tel;
   chkErr();       /* if any error occur, print out error */

   printf("John's telphone is %s\n", tel);

   /* test EXEC SQL DELETE (delete John Smith's tuple) */
   strcpy(name, "John Smith");
   EXEC SQL delete from info where name = :name :ind1;
   chkErr();       /* if any error occur, print out error */

   /* test EXEC SQL UPDATE (update Jane White's telephone number */
   strcpy(name, "Jane White");
   strcpy(tel, "7214346");
   EXEC SQL update info set tel = :tel :ind1 where name = :name :ind1;
   chkErr();       /* if any error occur, print out error */
   
   /* test CURSOR, fetch all tuple in info table           */
   /* test EXEC SQL DECLARE CURSOR for query all data in info table */
   EXEC SQL declare myCur cursor for 
            select name,tel from info into :name, :tel;
   chkErr();

   /* test EXEC SQL OPEN CURSOR */
   EXEC SQL open myCur;        /* open cursor */
   chkErr();

   while (1)
      {
      /* test EXEC SQL FETCH CURSOR */
      Exec SQL fetch myCur;   /* fetch cursor */
      chkErr();     /* print out error, if it's not SQL_NO_DATA_FOUND */
      if (SQLCODE)  /* If any SQLCODE occurs */
         {  /* If not warning (SQL_SUCCESS_WITH_INFO), break from loop */
         if (SQLCODE != SQL_SUCCESS_WITH_INFO)
            break;
         }
      printf("Name = %s, Tel = %s\n", name, tel);
      }

   /* test EXEC SQL CLOSE CURSOR */
   EXEC SQL close myCur;
   chkErr();

program_exit:
   /* if no error occurs, then commit transaction */
   if (SQLCODE == SQL_SUCCESS || SQLCODE == SQL_NO_DATA_FOUND ||
       SQLCODE == SQL_SUCCESS_WITH_INFO)
      {
      EXEC SQL commit work;
      if (SQLCODE)
         printf("ERR(%d):%s\n", sqlca.sqlerrd[0], sqlca.sqlerrmc);
      }
   else  /* if any error occurs, then rollback transaction */
      EXEC SQL rollback work;
   
   EXEC SQL disconnect;
   if (SQLCODE)
      printf("ERR(%d):%s\n", sqlca.sqlerrd[0], sqlca.sqlerrmc);  
}
