#!/bin/sh
#
# The startup and shutdown script for DBMaker database
#
# Linux chkconfig script:
# chkconfig: 2345 90 10
# description: Starts and stops the DBMaker dmserver daemons at boot time \
#              and shutdown.  DBMaker provides you with a professional \
#              database system with multimedia capabilities, a native ODBC \
#              interface, large database features, and cross-platform support.
# processname: dmserver
# config: /etc/dminit.conf
#

app_name=dbmaker
app_home=`awk -F: '$1~/^'${app_name}'$/ {print $6}' /etc/passwd`
app_conf=/etc/dminit.conf

linux_start() {
  awk -F: '$1!~/^#/ {print $1,$2,$3 }' ${app_conf} |
  while read app_db app_ver app_owner; do
    [ -n "${app_db}" -a -n "${app_ver}" -a -n "${app_owner}" ] || continue
    echo -n "Starting DBMaker ${app_db} service: "
    app_cmd="${app_home}/${app_ver}/bin/dmserver"
    daemon --user ${app_owner} ${app_cmd} ${app_db}
    echo
  done
  touch /var/lock/subsys/${app_name}
}

linux_stop() {
  awk -F: '$1!~/^#/ {print $1,$2,$3 }' ${app_conf} |
  while read app_db app_ver app_owner; do
    [ -n "${app_db}" -a -n "${app_ver}" -a -n "${app_owner}" ] || continue
    echo -n "Shutting down DBMaker ${app_db} service: "
    app_cmd="${app_home}/${app_ver}/bin/dmserver"
    ${app_cmd} -k ${app_db} 2>&1 >/dev/null && \
      success "${app_name} shutdown" || failure "${app_name} shutdown"
    echo
  done
  rm -f /var/lock/subsys/${app_name}
}

rcCHKCFG() {
  # Source function library
  if [ -f /etc/init.d/functions ]; then
    . /etc/init.d/functions
  elif [ -f /etc/rc.d/init.d/functions ]; then
    . /etc/rc.d/init.d/functions
  else
    exit 0
  fi

  # Check that $app_conf exists.
  [ -f ${app_conf} ] || exit 0

  RETVAL=0

  case "$1" in
    start)
      linux_start
      ;;
    stop)
      linux_stop
      ;;
    restart)
      linux_stop
      sleep 5
      linux_start
      ;;
    *)
      echo "Usage: `basename $0` { start | stop | restart }"
      exit 64
      ;;
  esac

  exit $RETVAL
}

rcCHKCFG "$1"
